<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://cloudimage.io
 * @since             1.0.0
 * @package           Cloudimg
 *
 * @wordpress-plugin
 * Plugin Name:       Cloudimage.io
 * Plugin URI:        https://cloudimage.io
 * Description:       The easiest way to <strong>resize, compress, optimise and deliver</strong> your images to your customers through <strong>rocket fast CDNs</strong>.
 * Version:           1.0.0
 * Author:            Cloudimage
 * Author URI:        https://cloudimage.io
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       cloudimg
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'PLUGIN_NAME_VERSION', '1.0.0' );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-cloudimg-activator.php
 */
function activate_cloudimg() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-cloudimg-activator.php';
	Cloudimg_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-cloudimg-deactivator.php
 */
function deactivate_cloudimg() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-cloudimg-deactivator.php';
	Cloudimg_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_cloudimg' );
register_deactivation_hook( __FILE__, 'deactivate_cloudimg' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-cloudimg.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_cloudimg() {

	$plugin = new Cloudimg();
	$plugin->run();

}
run_cloudimg();
